import { Switch, Route } from "wouter";
import { queryClient } from "./lib/queryClient";
import { QueryClientProvider } from "@tanstack/react-query";
import { Toaster } from "@/components/ui/toaster";
import NotFound from "@/pages/not-found";
import AuthPage from "@/pages/auth-page";
import LandingPage from "@/pages/landing-page";
import DashboardPage from "@/pages/dashboard-page";
import MoviesPage from "@/pages/movies-page";
import SeriesPage from "@/pages/series-page";
import ChannelsPage from "@/pages/channels-page";
import MatchesPage from "@/pages/matches-page";
import MatchSchedulePage from "@/pages/match-schedule-page";
import CategoriesPage from "@/pages/categories-page";
import SubcategoriesPage from "@/pages/subcategories-page";
import FetcherPage from "@/pages/fetcher-page";
import NotificationsPage from "@/pages/notifications-page";
import SettingsPage from "@/pages/settings-page";
import PrivacyPolicyPage from "@/pages/privacy-policy-page";
import TermsPage from "@/pages/terms-page";
import AboutPage from "@/pages/about-page";
import FAQPage from "@/pages/faq-page";
import ContactPage from "@/pages/contact-page";
import HelpCenterPage from "@/pages/help-center-page";
import DownloadsPage from "@/pages/downloads-page";
import { AuthProvider } from "@/hooks/use-auth";
import { ProtectedRoute } from "@/lib/protected-route";

function Router() {
  return (
    <Switch>
      {/* Public routes */}
      <Route path="/" component={LandingPage} />
      <Route path="/auth" component={AuthPage} />
      <Route path="/privacy" component={PrivacyPolicyPage} />
      <Route path="/terms" component={TermsPage} />
      <Route path="/about" component={AboutPage} />
      <Route path="/faq" component={FAQPage} />
      <Route path="/contact" component={ContactPage} />
      <Route path="/help-center" component={HelpCenterPage} />
      <Route path="/downloads" component={DownloadsPage} />
      
      {/* Protected admin routes */}
      <ProtectedRoute path="/dashboard" component={DashboardPage} />
      <ProtectedRoute path="/movies" component={MoviesPage} />
      <ProtectedRoute path="/series" component={SeriesPage} />
      <ProtectedRoute path="/channels" component={ChannelsPage} />
      <ProtectedRoute path="/matches" component={MatchesPage} />
      <ProtectedRoute path="/match-schedule" component={MatchSchedulePage} />
      <ProtectedRoute path="/categories" component={CategoriesPage} />
      <ProtectedRoute path="/subcategories" component={SubcategoriesPage} />
      <ProtectedRoute path="/fetcher" component={FetcherPage} />
      <ProtectedRoute path="/notifications" component={NotificationsPage} />
      <ProtectedRoute path="/settings" component={SettingsPage} />
      
      {/* 404 page */}
      <Route component={NotFound} />
    </Switch>
  );
}

function App() {
  return (
    <QueryClientProvider client={queryClient}>
      <AuthProvider>
        <Router />
        <Toaster />
      </AuthProvider>
    </QueryClientProvider>
  );
}

export default App;
