import { formatDistanceToNow } from "date-fns";
import { Button } from "@/components/ui/button";
import { Notification } from "@shared/schema";
import { cn } from "@/lib/utils";

interface NotificationItemProps {
  notification: Notification;
}

function NotificationItem({ notification }: NotificationItemProps) {
  const getIconByType = () => {
    switch (notification.type) {
      case "info":
        return { icon: "info", bgColor: "bg-blue-100", textColor: "text-primary" };
      case "warning":
        return { icon: "exclamation", bgColor: "bg-yellow-100", textColor: "text-warning" };
      case "error":
        return { icon: "times", bgColor: "bg-red-100", textColor: "text-error" };
      case "success":
        return { icon: "check", bgColor: "bg-green-100", textColor: "text-success" };
      default:
        return { icon: "info", bgColor: "bg-blue-100", textColor: "text-primary" };
    }
  };

  const { icon, bgColor, textColor } = getIconByType();
  const timeAgo = formatDistanceToNow(new Date(notification.createdAt), { addSuffix: true });

  return (
    <div className="p-4 hover:bg-gray-50">
      <div className="flex">
        <div className="flex-shrink-0 pt-0.5">
          <div className={cn("h-8 w-8 rounded-full flex items-center justify-center", bgColor)}>
            <i className={cn(`fas fa-${icon}`, textColor)}></i>
          </div>
        </div>
        <div className="ml-3 flex-1">
          <p className="text-sm font-medium text-gray-900">
            {notification.title}
          </p>
          <p className="text-xs text-gray-500">
            {notification.message}
          </p>
          <p className="text-xs text-gray-400 mt-1">
            {timeAgo}
          </p>
        </div>
      </div>
    </div>
  );
}

interface NotificationsProps {
  notifications: Notification[];
  onMarkAllRead: () => void;
}

export function Notifications({ notifications, onMarkAllRead }: NotificationsProps) {
  return (
    <div className="bg-white rounded-lg shadow-sm">
      <div className="px-6 py-4 border-b border-gray-200 flex justify-between items-center">
        <h2 className="font-bold text-gray-800">Recent Notifications</h2>
        <Button 
          variant="ghost" 
          className="text-sm text-primary hover:text-primary-dark"
          onClick={onMarkAllRead}
        >
          Mark All Read
        </Button>
      </div>
      <div className="divide-y divide-gray-200">
        {notifications.length === 0 ? (
          <div className="p-4 text-center text-gray-500">
            No notifications
          </div>
        ) : (
          notifications.map((notification) => (
            <NotificationItem 
              key={notification.id} 
              notification={notification} 
            />
          ))
        )}
      </div>
    </div>
  );
}
