import { Button } from "@/components/ui/button";
import { cn } from "@/lib/utils";

interface QuickActionButtonProps {
  label: string;
  icon: string;
  color: string;
  onClick: () => void;
}

function QuickActionButton({ label, icon, color, onClick }: QuickActionButtonProps) {
  return (
    <Button
      variant="ghost"
      className={cn(
        "flex flex-col items-center justify-center p-4 rounded-lg transition-colors h-auto",
        `bg-${color}-50 hover:bg-${color}-100`
      )}
      onClick={onClick}
    >
      <i className={`fas fa-${icon} text-${color}-600 text-xl mb-2`}></i>
      <span className="text-sm text-gray-700">{label}</span>
    </Button>
  );
}

interface QuickActionsProps {
  onAddMovie: () => void;
  onAddSeries: () => void;
  onAddChannel: () => void;
  onFetchContent: () => void;
}

export function QuickActions({
  onAddMovie,
  onAddSeries,
  onAddChannel,
  onFetchContent
}: QuickActionsProps) {
  return (
    <div className="bg-white rounded-lg shadow-sm">
      <div className="px-6 py-4 border-b border-gray-200">
        <h2 className="font-bold text-gray-800">Quick Actions</h2>
      </div>
      <div className="p-6 grid grid-cols-2 gap-4">
        <QuickActionButton
          label="Add Movie"
          icon="film"
          color="blue"
          onClick={onAddMovie}
        />
        <QuickActionButton
          label="Add Series"
          icon="tv"
          color="green"
          onClick={onAddSeries}
        />
        <QuickActionButton
          label="Add Channel"
          icon="broadcast-tower"
          color="orange"
          onClick={onAddChannel}
        />
        <QuickActionButton
          label="Fetch Content"
          icon="download"
          color="purple"
          onClick={onFetchContent}
        />
      </div>
    </div>
  );
}
