import { Link } from "wouter";
import { Button } from "@/components/ui/button";
import { useAuth } from "@/hooks/use-auth";
import { useQuery } from "@tanstack/react-query";
import { SiteSettings } from "@shared/schema";
import path from "path-browserify";
import {
  FilmIcon,
  TvIcon,
  PhoneIcon,
  BoltIcon,
  CheckCircleIcon,
  QrCodeIcon,
  ArrowRightIcon,
  ArrowDownTrayIcon,
} from "@heroicons/react/24/outline";
import { DevicePhoneMobileIcon } from "@heroicons/react/24/solid";

export default function LandingPage() {
  const { user } = useAuth();
  const { data: settings } = useQuery<SiteSettings>({
    queryKey: ["/api/settings"],
  });
  
  return (
    <div className="min-h-screen bg-white rtl">
      {/* Navbar */}
      <nav className="bg-white shadow-sm border-b border-gray-100">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="flex justify-between h-16">
            <div className="flex items-center">
              <Button 
                variant="outline" 
                asChild
                className="ml-2"
              >
                {user ? (
                  <Link to="/dashboard">لوحة التحكم</Link>
                ) : (
                  <Link to="/auth">تسجيل الدخول</Link>
                )}
              </Button>
              <Button 
                variant="link" 
                asChild
                className="text-gray-600 hover:text-primary ml-4"
              >
                <a href="#apps">التطبيقات</a>
              </Button>
              <Button 
                variant="link" 
                asChild
                className="text-gray-600 hover:text-primary ml-4"
              >
                <a href="#features">المميزات</a>
              </Button>
            </div>
            <div className="flex items-center">
              <div className="flex-shrink-0 flex items-center">
                <span className="text-xl font-bold text-primary ml-2">صقر تي في</span>
                <div className="w-8 h-8 rounded-full bg-primary flex items-center justify-center text-white">
                  <span className="text-lg font-bold">S</span>
                </div>
              </div>
            </div>
          </div>
        </div>
      </nav>

      {/* Hero Section */}
      <div className="bg-gradient-to-l from-primary/90 to-primary text-white">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-16 md:py-24 lg:py-32">
          <div className="grid grid-cols-1 md:grid-cols-2 gap-8 items-center">
            <div className="order-2 md:order-1 flex justify-center">
              <div className="relative w-[300px] h-[600px] rounded-[2.5rem] border-8 border-gray-800 bg-gray-800 shadow-xl">
                <div className="absolute top-0 inset-x-0 h-6 bg-gray-800 z-10"></div>
                <div className="h-full w-full overflow-hidden rounded-[2rem]">
                  <div className="bg-gradient-to-tr from-slate-900 to-primary/60 h-full w-full flex items-center justify-center">
                    <div className="text-center">
                      <div className="flex justify-center mb-3">
                        <div className="w-12 h-12 rounded-full bg-white flex items-center justify-center text-primary">
                          <span className="text-2xl font-bold">S</span>
                        </div>
                      </div>
                      <h3 className="text-white text-xl font-bold">صقر تي في</h3>
                      <p className="text-white/80 mt-1">استمتع بالمشاهدة في أي وقت وأي مكان</p>
                    </div>
                  </div>
                </div>
                <div className="absolute bottom-6 inset-x-0 h-1 w-1/3 bg-white mx-auto rounded-full"></div>
              </div>
            </div>
            <div className="order-1 md:order-2 text-right">
              <h1 className="text-4xl md:text-5xl font-bold mb-6">
                منصة الترفيه المتكاملة
              </h1>
              <p className="text-lg mb-8 text-white/90">
                منصة ترفيهية متميزة بواجهة مستخدم أنيقة وميزات متقدمة، 
                مصممة لتعزيز تجربة المشاهدة لديك.
              </p>
              <div className="flex flex-wrap gap-4 justify-end">
                <Button size="lg" variant="outline" className="bg-transparent text-white border-white hover:bg-white/10" asChild>
                  <a href="#features" className="flex items-center">
                    <ArrowRightIcon className="mr-2 h-5 w-5 rotate-180" />
                    استكشف المميزات
                  </a>
                </Button>
                <Button size="lg" variant="secondary" asChild>
                  <a href="#apps" className="flex items-center">
                    <DevicePhoneMobileIcon className="mr-2 h-5 w-5" />
                    تحميل التطبيق 
                  </a>
                </Button>
              </div>
            </div>
          </div>
        </div>
      </div>

      {/* Features Section */}
      <div id="features" className="py-16 bg-gray-50">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="text-center mb-16">
            <h2 className="text-3xl md:text-4xl font-bold text-gray-900 mb-4">
              مميزات متكاملة
            </h2>
            <p className="text-gray-600 max-w-3xl mx-auto">
              يقدم صقر تي في تجربة ترفيهية شاملة مع مجموعة واسعة من الميزات 
              المصممة لتعزيز متعة المشاهدة لديك.
            </p>
          </div>

          <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-8">
            <FeatureCard 
              icon={<FilmIcon className="h-8 w-8" />}
              title="محتوى ترفيهي"
              description="الوصول إلى محتوى عالي الجودة عبر مختلف الأنواع، منظم بعناية ويتم تحديثه بانتظام."
              iconBg="bg-blue-100"
              iconColor="text-blue-600"
            />
            <FeatureCard 
              icon={<TvIcon className="h-8 w-8" />}
              title="المسلسلات والعروض"
              description="استمتع بمواسم كاملة من البرامج الشعبية والدراما والمحتوى الحصري بسهولة."
              iconBg="bg-green-100"
              iconColor="text-green-600"
            />
            <FeatureCard 
              icon={<TvIcon className="h-8 w-8" />}
              title="القنوات المباشرة"
              description="الوصول إلى مجموعة متنوعة من القنوات المباشرة بما في ذلك الأخبار والرياضة والترفيه والمحتوى التعليمي."
              iconBg="bg-purple-100"
              iconColor="text-purple-600"
            />
            <FeatureCard 
              icon={<QrCodeIcon className="h-8 w-8" />}
              title="مشغل فيديو متكامل"
              description="يدعم صقر تي في تنسيقات فيديو متعددة، مما يوفر تشغيلًا سلسًا عبر جميع أنواع المحتوى."
              iconBg="bg-amber-100"
              iconColor="text-amber-600"
            />
            <FeatureCard 
              icon={<BoltIcon className="h-8 w-8" />}
              title="أداء عالي"
              description="تشغيل محسّن مع جودة متكيفة يضمن تجربة مشاهدة سلسة حتى مع اتصالات الإنترنت المتغيرة."
              iconBg="bg-red-100"
              iconColor="text-red-600"
            />
            <FeatureCard 
              icon={<PhoneIcon className="h-8 w-8" />}
              title="تجربة الجوال"
              description="تصميم متجاوب بالكامل يعمل بشكل مثالي على الهواتف الذكية والأجهزة اللوحية للترفيه أثناء التنقل."
              iconBg="bg-cyan-100"
              iconColor="text-cyan-600"
            />
          </div>
        </div>
      </div>

      {/* Apps Section */}
      <div id="apps" className="py-16">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="text-center mb-16">
            <h2 className="text-3xl md:text-4xl font-bold text-gray-900 mb-4">
              تطبيقاتنا
            </h2>
            <p className="text-gray-600 max-w-3xl mx-auto">
              قم بتنزيل تطبيقاتنا للاستمتاع بتجربة صقر الكاملة
              على جميع أجهزتك.
            </p>
          </div>

          <div className="max-w-3xl mx-auto">
            <AppCard 
              title="صقر تي في"
              description="تطبيقنا الشامل لتصفح والاستمتاع بالمحتوى المفضل لديك مع واجهة جميلة وبديهية، يتميز بمشغل وسائط متكامل مع قدرات متقدمة."
              features={[
                "تنظيم ذكي للمحتوى",
                "دعم لتنسيقات الوسائط المتعددة",
                "وضع الصورة داخل الصورة",
                "توصيات مخصصة",
                "تتبع المحتوى المشاهد والمفضل",
                "إشعارات قابلة للتخصيص",
                "التحكم في سرعة التشغيل",
                "تحكم متقدم بالإيماءات",
                "أداء محسّن مع إعلانات محدودة"
              ]}
              color="bg-gradient-to-l from-primary to-primary/80"
              version={settings?.appVersion ?? undefined}
              downloadUrl={settings?.appFilePath ? `/uploads/${path.basename(settings.appFilePath)}` : undefined}
              appName={settings?.appFileName ?? "saqr-tv.apk"}
            />
          </div>
        </div>
      </div>

      {/* CTA Section */}
      <div className="bg-primary py-12">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 text-center text-white">
          <h2 className="text-3xl font-bold mb-6">هل أنت مستعد للبدء؟</h2>
          <p className="text-white/90 mb-8 max-w-2xl mx-auto">
            قم بتنزيل صقر تي في اليوم واستمتع بتجربة ترفيهية متميزة.
            سهل الاستخدام، مصمم بشكل جميل، ومليء بالميزات.
          </p>
          {settings?.appFilePath ? (
            <Button 
              size="lg" 
              variant="secondary" 
              className="font-semibold"
              asChild
            >
              <a 
                href={`/uploads/${path.basename(settings.appFilePath)}`} 
                download={settings.appFileName || "saqr-tv.apk"}
                className="flex items-center"
              >
                <ArrowDownTrayIcon className="h-5 w-5 ml-2" />
                تحميل الآن
              </a>
            </Button>
          ) : (
            <Button 
              size="lg" 
              variant="secondary" 
              className="font-semibold"
              onClick={() => window.scrollTo({ top: document.getElementById('apps')?.offsetTop, behavior: 'smooth' })}
            >
              عرض التطبيق
            </Button>
          )}
          {settings?.appVersion && (
            <div className="mt-4 text-white/80 text-sm">
              آخر إصدار: {settings.appVersion}
            </div>
          )}
        </div>
      </div>

      {/* Footer */}
      <footer className="bg-gray-900 text-white py-12">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="flex flex-col md:flex-row justify-between items-center">
            <div className="grid grid-cols-2 md:grid-cols-3 gap-8 text-right">
              <div>
                <h5 className="font-semibold mb-4">روابط قانونية</h5>
                <ul className="space-y-2">
                  <li><Link to="/about" className="text-gray-400 hover:text-white">من نحن</Link></li>
                  <li><Link to="/privacy" className="text-gray-400 hover:text-white">سياسة الخصوصية</Link></li>
                  <li><Link to="/terms" className="text-gray-400 hover:text-white">شروط الاستخدام</Link></li>
                </ul>
              </div>
              <div>
                <h5 className="font-semibold mb-4">الدعم</h5>
                <ul className="space-y-2">
                  <li><Link to="/help-center" className="text-gray-400 hover:text-white">مركز المساعدة</Link></li>
                  <li><Link to="/contact" className="text-gray-400 hover:text-white">اتصل بنا</Link></li>
                  <li><Link to="/faq" className="text-gray-400 hover:text-white">الأسئلة الشائعة</Link></li>
                </ul>
              </div>
              <div>
                <h5 className="font-semibold mb-4">المنتج</h5>
                <ul className="space-y-2">
                  <li><a href="#features" className="text-gray-400 hover:text-white">المميزات</a></li>
                  <li><a href="#apps" className="text-gray-400 hover:text-white">التطبيقات</a></li>
                  <li><a href="#apps" className="text-gray-400 hover:text-white">التحميل</a></li>
                </ul>
              </div>
            </div>
            <div className="mb-6 md:mb-0 text-right">
              <div className="flex items-center justify-end">
                <span className="text-xl font-bold ml-2">صقر تي في</span>
                <div className="w-8 h-8 rounded-full bg-white flex items-center justify-center text-primary">
                  <span className="text-lg font-bold">S</span>
                </div>
              </div>
              <p className="text-gray-400 mt-2 max-w-xs">
                منصة ترفيهية متميزة لجميع احتياجاتك من الوسائط المتعددة
              </p>
            </div>
          </div>
          <div className="border-t border-gray-800 mt-12 pt-8 text-center">
            <p className="text-gray-400">© {new Date().getFullYear()} صقر تي في. جميع الحقوق محفوظة.</p>
          </div>
        </div>
      </footer>
    </div>
  );
}

function FeatureCard({ 
  icon, 
  title, 
  description, 
  iconBg, 
  iconColor 
}: { 
  icon: React.ReactNode; 
  title: string; 
  description: string; 
  iconBg: string; 
  iconColor: string; 
}) {
  return (
    <div className="bg-white rounded-xl shadow-sm border border-gray-100 p-6 transition-all duration-200 hover:shadow-md text-right">
      <div className={`${iconBg} ${iconColor} w-14 h-14 rounded-lg flex items-center justify-center mb-4 mr-auto`}>
        {icon}
      </div>
      <h3 className="text-xl font-semibold text-gray-900 mb-2">{title}</h3>
      <p className="text-gray-600">{description}</p>
    </div>
  );
}

function AppCard({ 
  title, 
  description, 
  features, 
  color,
  version,
  downloadUrl,
  appName
}: { 
  title: string; 
  description: string; 
  features: string[]; 
  color: string;
  version?: string;
  downloadUrl?: string;
  appName?: string;
}) {
  return (
    <div className="rounded-xl overflow-hidden shadow-lg border border-gray-100">
      <div className={`${color} px-8 py-6 text-white text-right`}>
        <h3 className="text-2xl font-bold mb-2">{title}</h3>
        <p className="text-white/90">{description}</p>
        {version && (
          <div className="mt-4 bg-white/20 text-white px-3 py-1 rounded-full inline-block">
            نسخة {version}
          </div>
        )}
      </div>
      <div className="bg-white p-8">
        <h4 className="text-lg font-semibold mb-4 text-right">المميزات الرئيسية:</h4>
        <ul className="space-y-3">
          {features.map((feature, index) => (
            <li key={index} className="flex items-start flex-row-reverse text-right">
              <CheckCircleIcon className="h-5 w-5 text-primary flex-shrink-0 ml-2 mt-0.5" />
              <span>{feature}</span>
            </li>
          ))}
        </ul>
        <div className="mt-8">
          {downloadUrl ? (
            <Button 
              className="w-full" 
              asChild
            >
              <a href={downloadUrl} download={appName} className="flex items-center justify-center">
                <ArrowDownTrayIcon className="h-5 w-5 ml-2" />
                تحميل التطبيق
              </a>
            </Button>
          ) : (
            <Button className="w-full" disabled>
              التطبيق غير متاح حالياً
            </Button>
          )}
        </div>
        {appName && downloadUrl && (
          <p className="mt-4 text-center text-gray-500 text-sm">
            اسم الملف: {appName}
          </p>
        )}
      </div>
    </div>
  );
}