import { ArrowLeft } from "lucide-react";
import { Link } from "wouter";
import { Button } from "@/components/ui/button";

export default function PrivacyPolicyPage() {
  return (
    <div className="min-h-screen bg-gray-50 py-8 dir-rtl">
      <div className="container mx-auto px-4 max-w-4xl">
        <div className="flex mb-8">
          <Button variant="ghost" asChild className="gap-2">
            <Link href="/">
              <ArrowLeft className="h-4 w-4" />
              <span>العودة إلى الصفحة الرئيسية</span>
            </Link>
          </Button>
        </div>
        
        <div className="bg-white p-8 rounded-lg shadow-sm">
          <h1 className="text-3xl font-bold mb-6 text-center">سياسة الخصوصية</h1>
          
          <div className="prose prose-lg max-w-none">
            <p className="mb-4">
              مرحبًا بك في تطبيق صقر تي في. نحن نلتزم بحماية خصوصيتك ونسعى جاهدين لضمان أمان معلوماتك الشخصية. تصف سياسة الخصوصية هذه كيفية جمعنا واستخدامنا وحمايتنا لمعلوماتك عند استخدام تطبيقنا.
            </p>
            
            <h2 className="text-xl font-semibold mt-6 mb-3">المعلومات التي نجمعها</h2>
            <p className="mb-4">
              قد نقوم بجمع أنواع المعلومات التالية:
            </p>
            <ul className="list-disc list-inside mb-4 space-y-2">
              <li>معلومات الجهاز والاتصال (مثل نوع الجهاز، نظام التشغيل، ومعلومات الشبكة)</li>
              <li>تفضيلات المحتوى والإعدادات المخصصة</li>
              <li>بيانات الاستخدام لتحسين تجربتك</li>
            </ul>
            
            <h2 className="text-xl font-semibold mt-6 mb-3">كيفية استخدام المعلومات</h2>
            <p className="mb-4">
              نستخدم المعلومات التي نجمعها للأغراض التالية:
            </p>
            <ul className="list-disc list-inside mb-4 space-y-2">
              <li>تقديم وتحسين خدماتنا</li>
              <li>تخصيص تجربة المستخدم</li>
              <li>تحليل كيفية استخدام التطبيق</li>
              <li>تحسين أمان وموثوقية خدماتنا</li>
            </ul>
            
            <h2 className="text-xl font-semibold mt-6 mb-3">الإعلانات</h2>
            <p className="mb-4">
              يستخدم تطبيقنا إعلانات من جوجل AdMob. قد تقوم خدمات الإعلانات هذه بجمع واستخدام البيانات لتقديم إعلانات ذات صلة. يمكنك الاطلاع على سياسة خصوصية Google للحصول على مزيد من المعلومات حول كيفية استخدام Google للبيانات.
            </p>
            
            <h2 className="text-xl font-semibold mt-6 mb-3">حماية البيانات</h2>
            <p className="mb-4">
              نحن نتخذ خطوات معقولة لحماية معلوماتك من الفقدان أو الوصول غير المصرح به أو الإفصاح. ومع ذلك، لا يمكن ضمان أمان المعلومات المرسلة عبر الإنترنت بنسبة 100٪.
            </p>
            
            <h2 className="text-xl font-semibold mt-6 mb-3">التغييرات على سياسة الخصوصية</h2>
            <p className="mb-4">
              قد نقوم بتحديث سياسة الخصوصية هذه من وقت لآخر. سنقوم بإخطارك بأي تغييرات عن طريق نشر السياسة الجديدة على هذه الصفحة.
            </p>
            
            <h2 className="text-xl font-semibold mt-6 mb-3">اتصل بنا</h2>
            <p className="mb-4">
              إذا كان لديك أي أسئلة حول سياسة الخصوصية هذه، يرجى الاتصال بنا عبر البريد الإلكتروني: support@saqrtv.com
            </p>
            
            <p className="mt-8 text-sm text-gray-600">
              آخر تحديث: {new Date().toLocaleDateString('ar-SA', { year: 'numeric', month: 'long', day: 'numeric' })}
            </p>
          </div>
        </div>
      </div>
    </div>
  );
}