#!/bin/bash

# Color codes for better readability
GREEN='\033[0;32m'
YELLOW='\033[1;33m'
RED='\033[0;31m'
NC='\033[0m' # No Color

echo -e "${GREEN}=== Saqr TV Backend Installation ===${NC}"
echo -e "${YELLOW}This script will install the Saqr TV backend server and web application.${NC}"
echo

# Check if Node.js is installed
if ! command -v node &> /dev/null; then
    echo -e "${RED}Node.js is not installed.${NC}"
    echo -e "Please install Node.js version 16 or higher from https://nodejs.org/"
    exit 1
fi

# Check Node.js version
NODE_VERSION=$(node -v | cut -d'v' -f2 | cut -d'.' -f1)
if [ "$NODE_VERSION" -lt 16 ]; then
    echo -e "${RED}Your Node.js version is too old.${NC}"
    echo -e "You have Node.js version $(node -v), but version 16 or higher is required."
    echo -e "Please update your Node.js installation from https://nodejs.org/"
    exit 1
fi

echo -e "${YELLOW}Installing dependencies... This may take a few minutes.${NC}"
npm install

# Create .env file if it doesn't exist
if [ ! -f ".env" ]; then
    echo -e "${YELLOW}Creating .env file...${NC}"
    echo "DATABASE_URL=postgresql://username:password@localhost:5432/saqrtv" > .env
    echo "SESSION_SECRET=$(openssl rand -hex 32)" >> .env
    echo -e "${GREEN}Created .env file. Please edit it with your database credentials.${NC}"
    echo -e "You can edit this file using any text editor."
    echo
fi

echo -e "${GREEN}Installation complete!${NC}"
echo -e "To start the backend server, run: ${YELLOW}npm run dev${NC}"
echo
echo -e "${YELLOW}Important: Before starting the server, make sure to:${NC}"
echo -e "1. Edit the .env file with your database credentials"
echo -e "2. Create the database and run: ${YELLOW}npm run db:push${NC}"
echo
echo -e "For more details, see the README.md file."