import { Link, useLocation } from "wouter";
import { cn } from "@/lib/utils";
import { useAuth } from "@/hooks/use-auth";

interface SidebarItemProps {
  href: string;
  icon: string;
  label: string;
  isActive: boolean;
}

const SidebarItem = ({ href, icon, label, isActive }: SidebarItemProps) => {
  return (
    <Link href={href}>
      <div 
        className={cn(
          "flex items-center px-4 py-3 text-gray-700 hover:bg-gray-50 cursor-pointer",
          isActive && "bg-blue-50 border-l-4 border-primary"
        )}
      >
        <i className={`fas fa-${icon} w-6`}></i>
        <span>{label}</span>
      </div>
    </Link>
  );
};

interface SidebarProps {
  className?: string;
}

export function Sidebar({ className }: SidebarProps) {
  const [location] = useLocation();
  const { user } = useAuth();

  if (!user) return null;

  return (
    <div className={cn("w-64 bg-white shadow-md hidden md:block h-full overflow-y-auto", className)}>
      <div className="px-6 py-4 border-b border-gray-200">
        <h1 className="text-2xl font-bold text-primary flex items-center">
          <i className="fas fa-play-circle mr-2"></i> Saqr Admin
        </h1>
      </div>
      <div className="py-2">
        <p className="px-6 py-2 text-xs font-semibold text-gray-500 uppercase">Main</p>
        <SidebarItem 
          href="/dashboard" 
          icon="tachometer-alt" 
          label="Dashboard" 
          isActive={location === "/dashboard"}
        />
        <SidebarItem 
          href="/movies" 
          icon="film" 
          label="Movies" 
          isActive={location === "/movies"}
        />
        <SidebarItem 
          href="/series" 
          icon="tv" 
          label="TV Series" 
          isActive={location === "/series"}
        />
        <SidebarItem 
          href="/channels" 
          icon="broadcast-tower" 
          label="Live Channels" 
          isActive={location === "/channels"}
        />
        <SidebarItem 
          href="/matches" 
          icon="futbol" 
          label="Live Matches" 
          isActive={location === "/matches"}
        />
        <SidebarItem 
          href="/match-schedule" 
          icon="calendar-alt" 
          label="Match Schedule" 
          isActive={location === "/match-schedule"}
        />
        <p className="px-6 py-2 mt-2 text-xs font-semibold text-gray-500 uppercase">Management</p>
        <SidebarItem 
          href="/categories" 
          icon="layer-group" 
          label="Categories" 
          isActive={location === "/categories"}
        />
        <SidebarItem 
          href="/subcategories" 
          icon="folder-tree" 
          label="Subcategories" 
          isActive={location === "/subcategories"}
        />
        <SidebarItem 
          href="/fetcher" 
          icon="download" 
          label="Content Fetcher" 
          isActive={location === "/fetcher"}
        />
        <SidebarItem 
          href="/notifications" 
          icon="bell" 
          label="Notifications" 
          isActive={location === "/notifications"}
        />
        <SidebarItem 
          href="/settings" 
          icon="cog" 
          label="Settings" 
          isActive={location === "/settings"}
        />
      </div>
    </div>
  );
}
