import { ArrowLeft } from "lucide-react";
import { Link } from "wouter";
import { Button } from "@/components/ui/button";

export default function AboutPage() {
  return (
    <div className="min-h-screen bg-gray-50 py-8 dir-rtl">
      <div className="container mx-auto px-4 max-w-4xl">
        <div className="flex mb-8">
          <Button variant="ghost" asChild className="gap-2">
            <Link href="/">
              <ArrowLeft className="h-4 w-4" />
              <span>العودة إلى الصفحة الرئيسية</span>
            </Link>
          </Button>
        </div>
        
        <div className="bg-white p-8 rounded-lg shadow-sm">
          <div className="flex justify-center mb-6">
            <div className="w-16 h-16 rounded-full bg-primary flex items-center justify-center text-white">
              <span className="text-3xl font-bold">S</span>
            </div>
          </div>
          
          <h1 className="text-3xl font-bold mb-6 text-center">حول صقر تي في</h1>
          
          <div className="prose prose-lg max-w-none">
            <p className="mb-6 text-center">
              صقر تي في هو منصة ترفيهية متكاملة توفر تجربة مشاهدة فريدة ومتنوعة لجميع المستخدمين.
            </p>
            
            <h2 className="text-xl font-semibold mt-8 mb-4">رؤيتنا</h2>
            <p className="mb-6">
              نسعى لتوفير منصة سهلة الاستخدام تجمع كل احتياجات المشاهدة الترفيهية في مكان واحد، مع تقديم تجربة مستخدم متميزة وسلسة تتناسب مع مختلف الأذواق والاحتياجات.
            </p>
            
            <h2 className="text-xl font-semibold mt-8 mb-4">قصتنا</h2>
            <p className="mb-6">
              بدأت فكرة صقر تي في من الحاجة إلى منصة ترفيهية شاملة تلبي احتياجات المستخدم العربي. تأسست المنصة بهدف توفير حل متكامل يجمع بين سهولة الاستخدام والمحتوى المتنوع والجودة العالية.
            </p>
            <p className="mb-6">
              منذ إطلاقها، تطورت المنصة لتشمل مجموعة واسعة من المحتوى الترفيهي بما في ذلك الأفلام والمسلسلات والقنوات المباشرة والمباريات الرياضية. نحن نسعى باستمرار لتحسين تجربة المستخدم وإضافة ميزات جديدة.
            </p>
            
            <h2 className="text-xl font-semibold mt-8 mb-4">ما يميزنا</h2>
            <div className="grid grid-cols-1 md:grid-cols-2 gap-6 mb-8">
              <div className="bg-gray-50 p-4 rounded-lg">
                <h3 className="font-semibold mb-2">تنوع المحتوى</h3>
                <p>توفير محتوى متنوع يشمل الأفلام، المسلسلات، القنوات المباشرة، والمباريات الرياضية.</p>
              </div>
              
              <div className="bg-gray-50 p-4 rounded-lg">
                <h3 className="font-semibold mb-2">تصميم سهل الاستخدام</h3>
                <p>واجهة مستخدم بسيطة وسلسة تسهل الوصول للمحتوى المطلوب بأقل جهد ممكن.</p>
              </div>
              
              <div className="bg-gray-50 p-4 rounded-lg">
                <h3 className="font-semibold mb-2">دعم أنواع متعددة من الملفات</h3>
                <p>تشغيل مختلف أنواع ملفات الفيديو بكفاءة عالية.</p>
              </div>
              
              <div className="bg-gray-50 p-4 rounded-lg">
                <h3 className="font-semibold mb-2">تحديثات مستمرة</h3>
                <p>تطوير مستمر للتطبيق وإضافة ميزات جديدة بناءً على ملاحظات المستخدمين.</p>
              </div>
            </div>
            
            <h2 className="text-xl font-semibold mt-8 mb-4">فريقنا</h2>
            <p className="mb-6">
              يتكون فريقنا من مجموعة من المطورين والمصممين المتحمسين الذين يشتركون في رؤية واحدة: توفير تجربة ترفيهية متميزة للمستخدم العربي. نعمل بشكل مستمر على تطوير وتحسين التطبيق لتلبية توقعات مستخدمينا.
            </p>
            
            <h2 className="text-xl font-semibold mt-8 mb-4">تواصل معنا</h2>
            <p className="mb-6">
              نحن نقدر ملاحظاتك واقتراحاتك. يمكنك التواصل معنا عبر:
            </p>
            <ul className="list-disc list-inside mb-6 space-y-2">
              <li>البريد الإلكتروني: support@saqrtv.com</li>
              <li>من خلال صفحتنا على منصات التواصل الاجتماعي</li>
            </ul>
            
            <p className="mt-8 text-center text-gray-600">
              شكراً لاختيارك صقر تي في - المنصة الترفيهية المتكاملة
            </p>
          </div>
        </div>
      </div>
    </div>
  );
}