import { Button } from "@/components/ui/button";
import { Card, CardContent, CardDescription, CardFooter, CardHeader, CardTitle } from "@/components/ui/card";
import { Separator } from "@/components/ui/separator";
import { FileDown } from "lucide-react";

export default function DownloadsPage() {
  // Get the current URL to construct download links
  const baseUrl = window.location.origin;

  return (
    <div dir="rtl" className="container mx-auto py-8">
      <h1 className="text-3xl font-bold mb-6 text-center bg-gradient-to-r from-primary to-primary/60 text-transparent bg-clip-text">
        تحميل منصة صقر تي في
      </h1>
      <h2 className="text-xl mb-8 text-center text-muted-foreground">
        قم بتنزيل مكونات منصة صقر تي في من هنا
      </h2>

      <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6 max-w-6xl mx-auto">
        <Card className="shadow-lg hover:shadow-xl transition-shadow duration-300">
          <CardHeader>
            <CardTitle className="text-primary">موقع ولوحة إدارة صقر تي في</CardTitle>
            <CardDescription>
              لوحة الإدارة الكاملة والموقع الإلكتروني لمنصة صقر تي في
            </CardDescription>
          </CardHeader>
          <CardContent>
            <ul className="list-disc list-inside space-y-2 text-sm text-muted-foreground">
              <li>لوحة تحكم كاملة المميزات</li>
              <li>نظام إدارة المحتوى</li>
              <li>واجهة برمجة التطبيقات API</li>
              <li>دعم قاعدة البيانات</li>
            </ul>
          </CardContent>
          <CardFooter>
            <Button className="w-full" asChild>
              <a href={`${baseUrl}/deployment/saqr-tv-backend.zip`} download>
                <FileDown className="mr-2 h-4 w-4" /> تحميل الموقع ولوحة الإدارة
              </a>
            </Button>
          </CardFooter>
        </Card>

        <Card className="shadow-lg hover:shadow-xl transition-shadow duration-300">
          <CardHeader>
            <CardTitle className="text-primary">تطبيق صقر تي في</CardTitle>
            <CardDescription>
              التطبيق الرئيسي لمشاهدة المحتوى على الأجهزة المحمولة
            </CardDescription>
          </CardHeader>
          <CardContent>
            <ul className="list-disc list-inside space-y-2 text-sm text-muted-foreground">
              <li>واجهة مستخدم سهلة الاستخدام</li>
              <li>تصفح جميع أنواع المحتوى</li>
              <li>دعم للغة العربية</li>
              <li>تكامل مع مشغل صقر</li>
            </ul>
          </CardContent>
          <CardFooter>
            <Button className="w-full" asChild>
              <a href={`${baseUrl}/deployment/saqr-tv-mobile-app.zip`} download>
                <FileDown className="mr-2 h-4 w-4" /> تحميل تطبيق صقر تي في
              </a>
            </Button>
          </CardFooter>
        </Card>

        <Card className="shadow-lg hover:shadow-xl transition-shadow duration-300">
          <CardHeader>
            <CardTitle className="text-primary">مشغل صقر</CardTitle>
            <CardDescription>
              مشغل فيديو مستقل مع دعم للإعلانات
            </CardDescription>
          </CardHeader>
          <CardContent>
            <ul className="list-disc list-inside space-y-2 text-sm text-muted-foreground">
              <li>دعم لصيغ الفيديو المختلفة</li>
              <li>تكامل مع إعلانات AdMob</li>
              <li>ميزات تشغيل متقدمة</li>
              <li>تحسين تجربة المشاهدة</li>
            </ul>
          </CardContent>
          <CardFooter>
            <Button className="w-full" asChild>
              <a href={`${baseUrl}/deployment/saqr-player.zip`} download>
                <FileDown className="mr-2 h-4 w-4" /> تحميل مشغل صقر
              </a>
            </Button>
          </CardFooter>
        </Card>
      </div>

      <Separator className="my-8" />

      <div className="max-w-xl mx-auto">
        <Card className="shadow-xl border-primary/30">
          <CardHeader>
            <CardTitle className="text-center text-primary">حزمة صقر تي في الكاملة</CardTitle>
            <CardDescription className="text-center">
              جميع مكونات منصة صقر تي في في حزمة واحدة
            </CardDescription>
          </CardHeader>
          <CardContent>
            <p className="text-center text-muted-foreground mb-4">
              تحتوي هذه الحزمة على جميع المكونات مجمعة في ملف واحد:
            </p>
            <ul className="list-disc list-inside space-y-2 text-sm text-muted-foreground">
              <li>موقع ولوحة إدارة صقر تي في</li>
              <li>تطبيق صقر تي في للهواتف المحمولة</li>
              <li>مشغل صقر مع دعم الإعلانات</li>
              <li>دليل التثبيت والتكوين</li>
            </ul>
          </CardContent>
          <CardFooter>
            <Button className="w-full" size="lg" asChild>
              <a href={`${baseUrl}/deployment/saqr-tv-full-package.zip`} download>
                <FileDown className="mr-2 h-5 w-5" /> تحميل الحزمة الكاملة
              </a>
            </Button>
          </CardFooter>
        </Card>
      </div>

      <div className="mt-12 text-center text-muted-foreground">
        <p>للحصول على مزيد من المعلومات والدعم الفني، يرجى الاطلاع على دليل المستخدم المرفق مع كل حزمة.</p>
        <p className="mt-2">© صقر تي في {new Date().getFullYear()}</p>
      </div>
    </div>
  );
}