import React from "react";
import { PublicLayout } from "@/components/public-layout";
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card";
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs";
import { Search } from "lucide-react";
import { Input } from "@/components/ui/input";
import { Button } from "@/components/ui/button";
import { Separator } from "@/components/ui/separator";
import { Link } from "wouter";

export default function HelpCenterPage() {
  const helpCategories = [
    {
      id: "general",
      title: "معلومات عامة",
      articles: [
        { id: "what-is", title: "ما هو صقر تي في؟", content: "صقر تي في هي منصة بث تتيح لك مشاهدة الأفلام والمسلسلات والقنوات التلفزيونية والمباريات الرياضية المباشرة. توفر المنصة محتوى متنوع ومحدث باستمرار." },
        { id: "get-started", title: "كيفية البدء مع صقر تي في", content: "لبدء استخدام صقر تي في، قم بتنزيل التطبيق من موقعنا الرسمي أو من متجر Google Play. بعد التثبيت، افتح التطبيق وستتمكن من الوصول إلى جميع المحتويات المتاحة مباشرة دون الحاجة إلى تسجيل الدخول." },
        { id: "supported-devices", title: "الأجهزة المدعومة", content: "يدعم تطبيق صقر تي في حاليًا أجهزة أندرويد بإصدار 5.0 وما فوق، بما في ذلك الهواتف الذكية والأجهزة اللوحية وأجهزة Android TV." },
      ],
    },
    {
      id: "technical",
      title: "الدعم الفني",
      articles: [
        { id: "connection-issues", title: "مشاكل الاتصال", content: "إذا كنت تواجه مشاكل في الاتصال، تأكد من استقرار اتصال الإنترنت لديك. جرب إعادة تشغيل التطبيق أو إعادة تشغيل جهازك. إذا استمرت المشكلة، يمكنك الاتصال بفريق الدعم الفني." },
        { id: "playback-issues", title: "مشاكل تشغيل الفيديو", content: "إذا كنت تواجه مشاكل في تشغيل الفيديو، تأكد من أن لديك اتصال إنترنت سريع وثابت. يمكنك أيضًا تجربة تقليل جودة الفيديو من إعدادات التطبيق." },
        { id: "app-crashes", title: "توقف التطبيق المفاجئ", content: "إذا كان التطبيق يتوقف بشكل مفاجئ، جرب تحديث التطبيق إلى أحدث إصدار أو إعادة تثبيته. تأكد أيضًا من توفر مساحة كافية على جهازك." },
      ],
    },
    {
      id: "content",
      title: "المحتوى",
      articles: [
        { id: "content-types", title: "أنواع المحتوى المتوفرة", content: "يوفر صقر تي في مجموعة متنوعة من المحتويات بما في ذلك الأفلام العربية والأجنبية، المسلسلات بمختلف حلقاتها ومواسمها، القنوات التلفزيونية المباشرة، والمباريات الرياضية والبطولات المباشرة." },
        { id: "request-content", title: "طلب محتوى جديد", content: "إذا كنت ترغب في طلب محتوى معين غير متوفر حاليًا، يمكنك إرسال طلبك من خلال صفحة 'اتصل بنا'. سنبذل قصارى جهدنا لتوفير المحتوى المطلوب في أقرب وقت ممكن." },
        { id: "content-schedule", title: "جدول المحتوى الجديد", content: "يتم تحديث المحتوى على صقر تي في بشكل منتظم. يمكنك متابعة الإشعارات داخل التطبيق أو صفحاتنا على وسائل التواصل الاجتماعي للبقاء على اطلاع بأحدث الإضافات." },
      ],
    },
  ];

  return (
    <PublicLayout title="مركز المساعدة">
      <div className="container mx-auto py-8 px-4 md:px-6">
        <Card className="mb-8">
          <CardHeader>
            <CardTitle className="text-2xl text-center">مركز المساعدة</CardTitle>
            <CardDescription className="text-center">
              ابحث عن إجابات لأسئلتك واستفساراتك
            </CardDescription>
          </CardHeader>
          <CardContent>
            <div className="relative max-w-xl mx-auto">
              <Search className="absolute left-3 top-3 h-5 w-5 text-muted-foreground" />
              <Input
                placeholder="ابحث عن سؤال أو موضوع..."
                className="pl-10 pr-4 text-right"
              />
            </div>
          </CardContent>
        </Card>

        <Tabs defaultValue="general" className="space-y-6">
          <TabsList className="grid grid-cols-3 w-full max-w-xl mx-auto">
            <TabsTrigger value="general">معلومات عامة</TabsTrigger>
            <TabsTrigger value="technical">الدعم الفني</TabsTrigger>
            <TabsTrigger value="content">المحتوى</TabsTrigger>
          </TabsList>

          {helpCategories.map((category) => (
            <TabsContent key={category.id} value={category.id} className="space-y-6">
              {category.articles.map((article, index) => (
                <Card key={article.id}>
                  <CardHeader>
                    <CardTitle className="text-xl text-right">{article.title}</CardTitle>
                  </CardHeader>
                  <CardContent>
                    <p className="text-right">{article.content}</p>
                    {index !== category.articles.length - 1 && (
                      <Separator className="my-4" />
                    )}
                  </CardContent>
                </Card>
              ))}
            </TabsContent>
          ))}
        </Tabs>

        <div className="mt-12 text-center">
          <h3 className="text-xl font-semibold mb-4">لم تجد ما تبحث عنه؟</h3>
          <div className="flex justify-center space-x-4">
            <Button asChild>
              <Link href="/contact">اتصل بنا</Link>
            </Button>
            <Button variant="outline" asChild>
              <Link href="/faq">الأسئلة الشائعة</Link>
            </Button>
          </div>
        </div>
      </div>
    </PublicLayout>
  );
}