#!/bin/bash

# Color codes for better readability
GREEN='\033[0;32m'
YELLOW='\033[1;33m'
RED='\033[0;31m'
NC='\033[0m' # No Color

echo -e "${GREEN}=== Saqr TV Mobile App Installation ===${NC}"
echo -e "${YELLOW}This script will install the Saqr TV mobile application development environment.${NC}"
echo

# Check if Node.js is installed
if ! command -v node &> /dev/null; then
    echo -e "${RED}Node.js is not installed.${NC}"
    echo -e "Please install Node.js version 16 or higher from https://nodejs.org/"
    exit 1
fi

# Check if npm is installed
if ! command -v npm &> /dev/null; then
    echo -e "${RED}npm is not installed.${NC}"
    echo -e "Please install Node.js (which includes npm) from https://nodejs.org/"
    exit 1
fi

# Install dependencies
echo -e "${YELLOW}Installing dependencies... This may take a few minutes.${NC}"
npm install

# Prompt for backend URL
echo
echo -e "${YELLOW}Please enter your backend server URL (e.g., http://192.168.1.100:3000):${NC}"
read -p "> " API_URL

# Create .env file
echo -e "${YELLOW}Creating .env file...${NC}"
echo "API_URL=$API_URL" > .env
echo -e "${GREEN}Created .env file with API_URL=$API_URL${NC}"

echo
echo -e "${GREEN}Installation complete!${NC}"
echo -e "To start the development server, run: ${YELLOW}npm start${NC}"
echo
echo -e "${YELLOW}Important:${NC}"
echo -e "1. Make sure your backend server is running"
echo -e "2. Install the Expo Go app on your mobile device"
echo -e "3. Scan the QR code that appears when you run 'npm start'"
echo
echo -e "For more details, see the README.md file."