#!/bin/bash

# Color codes for better readability
GREEN='\033[0;32m'
YELLOW='\033[1;33m'
RED='\033[0;31m'
NC='\033[0m' # No Color

echo -e "${GREEN}=== Saqr Player Installation ===${NC}"
echo -e "${YELLOW}This script will install the Saqr Player application development environment.${NC}"
echo

# Check if Node.js is installed
if ! command -v node &> /dev/null; then
    echo -e "${RED}Node.js is not installed.${NC}"
    echo -e "Please install Node.js version 16 or higher from https://nodejs.org/"
    exit 1
fi

# Install dependencies
echo -e "${YELLOW}Installing dependencies... This may take a few minutes.${NC}"
npm install

echo
echo -e "${GREEN}Installation complete!${NC}"
echo -e "To start the development server, run: ${YELLOW}npm start${NC}"
echo
echo -e "${YELLOW}Important:${NC}"
echo -e "1. Install the Expo Go app on your mobile device"
echo -e "2. Scan the QR code that appears when you run 'npm start'"
echo
echo -e "To build the production application:"
echo -e "1. Create an account at expo.dev"
echo -e "2. Install EAS CLI: ${YELLOW}npm install -g eas-cli${NC}"
echo -e "3. Login to EAS: ${YELLOW}eas login${NC}"
echo -e "4. Configure the build: ${YELLOW}eas build:configure${NC}"
echo -e "5. Build for Android: ${YELLOW}eas build -p android${NC}"
echo
echo -e "For more details, see the README.md file."