# Saqr TV Platform - Setup Guide

This guide is for users without programming experience who want to set up the Saqr TV platform.

## System Requirements

Before you begin, make sure you have:

1. A computer running Windows, macOS, or Linux
2. Node.js version 16 or higher installed
   - Download from: https://nodejs.org/ (choose the "LTS" version)
3. PostgreSQL database installed
   - Download from: https://www.postgresql.org/download/
4. A smartphone with Android or iOS for testing the mobile apps

## Step 1: Extract the Package

1. Download the Saqr TV package zip file
2. Extract the zip file to a folder on your computer

## Step 2: Set Up the Backend

1. Open a terminal or command prompt
2. Navigate to the extracted backend folder
3. Run the installation script:
   - On Windows: Double-click on `install-backend.bat`
   - On macOS/Linux: Open Terminal, navigate to the folder, and run `./install-backend.sh`
4. Follow the on-screen instructions to:
   - Create a PostgreSQL database
   - Configure your .env file with database credentials
   - Initialize the database
   - Start the backend server

## Step 3: Set Up the Mobile App

1. Open a terminal or command prompt
2. Navigate to the extracted mobile app folder
3. Run the installation script:
   - On Windows: Double-click on `install-mobile-app.bat`
   - On macOS/Linux: Open Terminal, navigate to the folder, and run `./install-mobile-app.sh`
4. Enter your backend server URL when prompted
   - This should be the IP address of your computer followed by port 3000 (e.g., http://192.168.1.100:3000)
5. Install the Expo Go app on your smartphone from the App Store or Google Play
6. Scan the QR code that appears to open the Saqr TV app on your phone

## Step 4: Set Up the Player App

1. Open a terminal or command prompt
2. Navigate to the extracted player app folder
3. Run the installation script:
   - On Windows: Double-click on `install-player.bat`
   - On macOS/Linux: Open Terminal, navigate to the folder, and run `./install-player.sh`
4. Install the Expo Go app on your smartphone (if you haven't already)
5. Scan the QR code that appears to open the Saqr Player on your phone

## Step 5: Access the Admin Panel

1. Open a web browser on your computer
2. Go to http://localhost:3000 (or the IP address of your computer followed by port 3000)
3. Click on the "Admin Login" button
4. Log in with the default credentials:
   - Username: admin
   - Password: password123
5. Change the default password in the Settings section

## Troubleshooting

### Common Issues

1. **Backend won't start**
   - Make sure PostgreSQL is running
   - Check your .env file has the correct database URL
   - Ensure Node.js is installed correctly

2. **Mobile app can't connect to backend**
   - Make sure the backend server is running
   - Check the IP address in the mobile app's .env file
   - Ensure your phone and computer are on the same network

3. **Player app not opening from Saqr TV app**
   - Make sure both apps are installed on the same device
   - Check that the Saqr Player app is installed correctly

### Getting Help

If you encounter issues not covered in this guide, please:

1. Refer to the detailed README.md files in each package
2. Contact our support team at support@saqrtv.com

## Next Steps

After successful setup, you can:

1. Add content to your Saqr TV platform through the admin panel
2. Customize your site settings
3. Create additional admin users
4. Set up categories and subcategories for your content
5. Upload your applications to app stores (for production use)

Remember to back up your database regularly to prevent data loss.